@@ -67,6 +67,8 @@ class R2Env:
         self.check_if_r2env_initialized()
         use_meson = kwargs["use_meson"] if "use_meson" in kwargs else False
         use_dist = kwargs["use_dist"] if "use_dist" in kwargs else False
+        if "@" not in package:
+            package = f"{package}@git"
         if not self._check_package_format(package):
             raise R2EnvException("[x] Invalid package format.")
         try:
@@ -106,17 +108,17 @@ class R2Env:
     @staticmethod
     def version():
         thispath = os.path.dirname(os.path.realpath(__file__))
-        with open(thispath + "/version.txt", "r", encoding="utf-8") as version:
-            return version.read()
+        with open(f"{thispath}/version.txt", "r", encoding="utf-8") as version:
+            print_console(version.read())
 
-    def shell(self, cmd="", **_kwargs):
+    def shell(self, cmd=None, **_kwargs):
         bin_path = os.path.join(self._r2env_path, "bin")
         if host_platform() == "windows":
             os.system(f"set PATH={bin_path};%PATH% && cmd")
             return True
         pkgconfig_path = os.path.join(self._r2env_path, "lib", "pkgconfig")
         bin_path = os.path.join(self._r2env_path, "bin")
-        export_ps1 = "export PS1=\"r2env\\$ \";"
+        export_ps1 = f"export PS1=\"r2env ({self._get_current_version()})\\$ \";"
         export_pkg_config = f"export PKG_CONFIG_PATH=\"{pkgconfig_path}\";"
         export_path = f"export PATH=\"{bin_path}:$PATH\";"
         cmd_shell = "$SHELL -f"
@@ -126,10 +128,11 @@ class R2Env:
             full_cmd = f"export LD_LIBRARY_PATH=\"{library_path}\";" + full_cmd
         if host_platform() == "osx":
             library_path = os.path.join(self._r2env_path, "lib")
+            # XXX this doesnt work on sip-enabled macs, that's why we use install_name_tool after install
             full_cmd = f"export DYLD_LIBRARY_PATH=\"{library_path}\";" + full_cmd
-        if cmd.strip() == "":
-            return os.system(full_cmd)
-        return os.system(full_cmd + " -c '" + cmd + "'")
+        if cmd is None:
+            return os.system(full_cmd) == 0
+        return os.system(f"{full_cmd} -c '{cmd}'") == 0
 
     @staticmethod
     def _load_config():
